## -*- coding: utf-8; -*-
<%inherit file="/page.mako" />

<%def name="title()">Generate Feature</%def>

<%def name="content_title()"></%def>

<%def name="extra_styles()">
  ${parent.extra_styles()}
  <style type="text/css">

    .content.result p {
        margin-bottom: 1rem;
    }

    .content.result .codehilite {
        margin-bottom: 2rem;
    }

  </style>
</%def>

<%def name="page_content()">

  <b-field horizontal label="App Prefix"
           message="Unique naming prefix for the app.">
    <b-input v-model="app.app_prefix"
             @input="appPrefixChanged">
    </b-input>
  </b-field>

  <b-field horizontal label="App CapPrefix"
           message="Unique naming prefix for the app, in CapWords style.">
    <b-input v-model="app.app_cap_prefix"></b-input>
  </b-field>

  <b-field horizontal label="Feature Type">
    <b-select v-model="featureType">
      <option value="new-report">New Report</option>
      <option value="new-table">New Table</option>
    </b-select>
  </b-field>

  <div v-if="featureType == 'new-table'">
    ${h.form(request.current_route_url(), ref='new-table-form')}
    ${h.csrf_token(request)}
    ${h.hidden('feature_type', value='new-table')}
    ${h.hidden('app_prefix', **{'v-model': 'app.app_prefix'})}
    ${h.hidden('app_cap_prefix', **{'v-model': 'app.app_cap_prefix'})}

    <br />
    <div class="card">
      <header class="card-header">
        <p class="card-header-title">New Table</p>
      </header>
      <div class="card-content">
        <div class="content">

          <b-field horizontal label="Table Name"
                   :message="`Name for the table within the DB.  With prefix this becomes: ${'$'}{app.app_prefix}_${'$'}{new_table.table_name}`">
            <b-input name="table_name"
                     v-model="new_table.table_name"
                     @input="tableNameChanged">
            </b-input>
          </b-field>

          <b-field horizontal label="Model Name"
                   :message="`Model name for the table, in CapWords style.  With prefix this becomes: ${'$'}{app.app_cap_prefix}${'$'}{new_table.model_name}`">
            <b-input name="model_name" v-model="new_table.model_name"></b-input>
          </b-field>

          <b-field horizontal label="Model Title"
                   message="Human-friendly singular model title.">
            <b-input name="model_title" v-model="new_table.model_title"></b-input>
          </b-field>

          <b-field horizontal label="Plural Model Title"
                   message="Human-friendly plural model title.">
            <b-input name="model_title_plural" v-model="new_table.model_title_plural"></b-input>
          </b-field>

          <b-field horizontal label="Description"
                   message="Description of what a record in this table represents.">
            <b-input name="description" v-model="new_table.description"></b-input>
          </b-field>

          <b-field horizontal label="Versioned"
                   message="Whether to record version data for this table.">
            <b-checkbox name="versioned"
                        v-model="new_table.versioned"
                        native-value="true">
              {{ new_table.versioned }}
            </b-checkbox>
          </b-field>

        </div>
      </div>
    </div>

    ${h.end_form()}
  </div>

  <div v-if="featureType == 'new-report'">
    ${h.form(request.current_route_url(), ref='new-report-form')}
    ${h.csrf_token(request)}
    ${h.hidden('feature_type', value='new-report')}
    ${h.hidden('app_prefix', **{'v-model': 'app.app_prefix'})}
    ${h.hidden('app_cap_prefix', **{'v-model': 'app.app_cap_prefix'})}

    <br />
    <div class="card">
      <header class="card-header">
        <p class="card-header-title">New Report</p>
      </header>
      <div class="card-content">
        <div class="content">

          <b-field horizontal label="Name"
                   message="Human-friendly name for the report.">
            <b-input name="name" v-model="new_report.name"></b-input>
          </b-field>

          <b-field horizontal label="Description"
                   message="Description of the report.">
            <b-input name="description" v-model="new_report.description"></b-input>
          </b-field>

        </div>
      </div>
    </div>

    ${h.end_form()}
  </div>

  <br />
  <div class="buttons" style="padding-left: 8rem;">
    <once-button type="is-primary"
                 @click="submitFeatureForm()"
                 text="Generate Feature">
    </once-button>
  </div>

  <div class="card"
       v-if="resultGenerated">
    <header class="card-header">
      <p class="card-header-title">
        <a name="instructions" href="#instructions">Please follow these instructions carefully.</a>
      </p>
    </header>
    <div class="card-content">
      <div class="content result">${rendered_result or ""|n}</div>
    </div>
  </div>

</%def>

<%def name="modify_this_page_vars()">
  ${parent.modify_this_page_vars()}
  <script type="text/javascript">

    ThisPageData.featureType = ${json.dumps(feature_type)|n}
    ThisPageData.resultGenerated = ${json.dumps(bool(result))|n}

    % if result:
    ThisPage.mounted = function() {
        location.href = '#instructions'
    }
    % endif

    ThisPageData.app = {
        <% dform = app_form.make_deform_form() %>
        % for field in dform:
            ${field.name}: ${app_form.get_vuejs_model_value(field)|n},
        % endfor
    }

    % for key, form in six.iteritems(feature_forms):
        <% safekey = key.replace('-', '_') %>
        ThisPageData.${safekey} = {
            <% dform = feature_forms[key].make_deform_form() %>
            % for field in dform:
                ${field.name}: ${feature_forms[key].get_vuejs_model_value(field)|n},
            % endfor
        }
    % endfor

    ThisPage.methods.appPrefixChanged = function(prefix) {
        let words = prefix.split('_')
        let capitalized = []
        words.forEach(word => {
            capitalized.push(word[0].toUpperCase() + word.substr(1))
        })

        this.app.app_cap_prefix = capitalized.join('')
    }

    ThisPage.methods.tableNameChanged = function(name) {
        let words = name.split('_')
        let capitalized = []
        words.forEach(word => {
            capitalized.push(word[0].toUpperCase() + word.substr(1))
        })

        this.new_table.model_name = capitalized.join('')
        this.new_table.model_title = capitalized.join(' ')
        this.new_table.model_title_plural = capitalized.join(' ') + 's'
        this.new_table.description = `Represents a ${'$'}{this.new_table.model_title}.`
    }

    ThisPage.methods.submitFeatureForm = function() {
        let form = this.$refs[this.featureType + '-form']
        form.submit()
    }

  </script>
</%def>


${parent.body()}
